/*
 * e-Knife, a program slicing tool for Erlang based on the EDG
 * Copyright (c) 2021. David Insa, Sergio Pérez, Josep Silva, Salvador Tamarit.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

package eknife.config;

import java.io.File;

public final class Config extends misc.Config
{
	/********************************************************************************************************************************/
	/************************************************************ STATIC ************************************************************/
	/********************************************************************************************************************************/
	private static final Config config = new Config();

	public static Config getConfig()
	{
		return Config.config;
	}

	/********************************************************************************************************************************/
	/************************************************************ OBJECT ************************************************************/
	/********************************************************************************************************************************/
	private final String scriptsPath;

	/****************************************************************/
	/************************* Constructor **************************/
	/****************************************************************/
	private Config()
	{
		this.scriptsPath = generateScriptsPath();
	}

	private String generateScriptsPath() {
		String[] suffixes = { "../../src/main/resources/", "ebin"};
		for (String suffix : suffixes) {
			String result = super.programPath + suffix;
			if (new File(result, "ast.beam").exists() && new File(result, "saver.beam").exists())
				return result;
		}
		throw new IllegalArgumentException("Can't find beam files. Place them in a folder './ebin' relative to the jar file.");
	}

	/****************************************************************/
	/**************************** Paths *****************************/
	/****************************************************************/
	public String getScriptsPath()
	{
		return this.scriptsPath;
	}

	/****************************************************************/
	/**************************** Files *****************************/
	/****************************************************************/
	public File getScriptsFile()
	{
		return new File(this.getScriptsPath());
	}
}