%%
 % e-Knife, a program slicing tool for Erlang based on the EDG
 % Copyright (c) 2021. David Insa, Sergio Pérez, Josep Silva, Salvador Tamarit.
 %
 % This program is free software: you can redistribute it and/or modify
 % it under the terms of the GNU Affero General Public License as
 % published by the Free Software Foundation, either version 3 of the
 % License, or (at your option) any later version.
 %
 % This program is distributed in the hope that it will be useful,
 % but WITHOUT ANY WARRANTY; without even the implied warranty of
 % MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 % GNU Affero General Public License for more details.
 %
 % You should have received a copy of the GNU Affero General Public License
 % along with this program.  If not, see <https://www.gnu.org/licenses/>.
 %

-module(ast).
-export([getASTs/1]).

getASTs(FileOrDir) ->
	case filename:extension(FileOrDir) of 
		[] -> % It is a directory
			getErlASTs(FileOrDir);
		_ ->  % It is a file
			getFileASTs(FileOrDir)
	end.

getErlASTs(FileOrDir) ->
	case filename:extension(FileOrDir) of 
		[] -> % It is a directory
			{ok, Files} = file:list_dir(FileOrDir),
			lists:concat([getErlASTs(filename:absname(F, FileOrDir)) || F <- Files]);
		".erl" -> % An erlang file
			getFileASTs(FileOrDir);
		_ -> % It is not an erlang file
			[]
	end.

getFileASTs(File) ->
	case epp:parse_file(File, [], []) of 
		{ok, Forms} -> % The ast has been obtained
			[Forms];
		_ -> % An error has occurred
			[]
	end.